==> org.eclipse.smartmdsd.xtext.base.stateMachine.ui.source_3.4.0.202110191307.jar: org/eclipse/smartmdsd/xtext/base/stateMachine/ui/StateMachineExecutableExtensionFactory.java <==
/********************************************************************************
 * Copyright (c) 2017 Technische Hochschule Ulm, Servicerobotics Ulm, Germany
 * headed by Prof. Dr. Christian Schlegel
 * 
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0 which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 * 
 * SPDX-License-Identifier: EPL-2.0
 * 
 * Contributors:
 *   Alex Lotz, Dennis Stampfer, Matthias Lutz
 ********************************************************************************/
package org.eclipse.smartmdsd.xtext.base.stateMachine.ui;

import com.google.inject.Injector;
import org.eclipse.core.runtime.Platform;
import org.eclipse.smartmdsd.xtext.base.stateMachine.ui.internal.StateMachineActivator;
import org.eclipse.xtext.ui.guice.AbstractGuiceAwareExecutableExtensionFactory;
import org.osgi.framework.Bundle;

/**
 * This class was generated. Customizations should only happen in a newly
 * introduced subclass. 
 */
public class StateMachineExecutableExtensionFactory extends AbstractGuiceAwareExecutableExtensionFactory {

	@Override
	protected Bundle getBundle() {
		return Platform.getBundle(StateMachineActivator.PLUGIN_ID);
	}
	
	@Override
	protected Injector getInjector() {
		StateMachineActivator activator = StateMachineActivator.getInstance();
		return activator != null ? activator.getInjector(StateMachineActivator.ORG_ECLIPSE_SMARTMDSD_XTEXT_BASE_STATEMACHINE_STATEMACHINE) : null;
	}

}

==> org.eclipse.smartmdsd.xtext.base.stateMachine.ui.source_3.4.0.202112151625.jar: org/eclipse/smartmdsd/xtext/base/stateMachine/ui/StateMachineExecutableExtensionFactory.java <==
/********************************************************************************
 * Copyright (c) 2017 Technische Hochschule Ulm, Servicerobotics Ulm, Germany
 * headed by Prof. Dr. Christian Schlegel
 * 
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0 which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 * 
 * SPDX-License-Identifier: EPL-2.0
 * 
 * Contributors:
 *   Alex Lotz, Dennis Stampfer, Matthias Lutz
 ********************************************************************************/
package org.eclipse.smartmdsd.xtext.base.stateMachine.ui;

import com.google.inject.Injector;
import org.eclipse.smartmdsd.xtext.base.stateMachine.ui.internal.StateMachineActivator;
import org.eclipse.xtext.ui.guice.AbstractGuiceAwareExecutableExtensionFactory;
import org.osgi.framework.Bundle;
import org.osgi.framework.FrameworkUtil;

/**
 * This class was generated. Customizations should only happen in a newly
 * introduced subclass. 
 */
public class StateMachineExecutableExtensionFactory extends AbstractGuiceAwareExecutableExtensionFactory {

	@Override
	protected Bundle getBundle() {
		return FrameworkUtil.getBundle(StateMachineActivator.class);
	}
	
	@Override
	protected Injector getInjector() {
		StateMachineActivator activator = StateMachineActivator.getInstance();
		return activator != null ? activator.getInjector(StateMachineActivator.ORG_ECLIPSE_SMARTMDSD_XTEXT_BASE_STATEMACHINE_STATEMACHINE) : null;
	}

}
